@@ -6,7 +6,7 @@ def gather(hub, profiles):
     sub_profiles = {hub.acct.BACKEND_KEY: {"twine_pypirc": {}}}
     for name, ctx in profiles.get("twine", {}).items():
         sub_profiles[name] = {
-            "settings": settings.Settings(**ctx)
+            "settings": settings.Settings(non_interactive=True, **ctx)
         }
     return sub_profiles
 
@@ -17,6 +17,6 @@ def default(hub):
     """
     return {
         "settings": settings.Settings(
-            config_file=os.path.expanduser("~/.pypirc"),
+            non_interactive=True, config_file=os.path.expanduser("~/.pypirc"),
         )
     }
