@@ -35,6 +35,8 @@ async def run(
     acct_key: str,
     acct_profile: str,
 ):
+    print(f"Working directory: {root_path}")
+    print("Generating ctx")
     ctx = await hub.idem.ex.ctx(
         "exec.twine.",
         acct_file=acct_file,
@@ -42,21 +44,30 @@ async def run(
         acct_profile=acct_profile,
     )
     if skip is None:
+        print("Running full release process")
         skip = []
-    if "semantic" not in skip:
+    if "coerce" not in skip:
+        print("Coercing the version number to semantic style")
         version = str(semantic_version.Version.coerce(str(version)))
     if "version" not in skip:
+        print("Updating release version")
         hub.pop_release.version.set_ver(root_path, version)
+        print("Updating docs version")
         hub.pop_release.version.set_doc(root_path, version)
     if "test" not in skip:
+        print("Running tests")
         hub.pop_release.test.pytest(root_path)
     if "commit" not in skip:
+        print("Committing changes")
         hub.pop_release.git.commit(root_path, version)
     if "tag" not in skip:
+        print("Tagging commit")
         hub.pop_release.git.tag(root_path, version)
     if "clean" not in skip:
+        print("Cleaning up")
         hub.pop_release.dist.clean(root_path)
     if "build" not in skip:
+        print("Building dist files")
         hub.pop_release.dist.build(root_path)
     if "input" in skip:
         choice = "y"
@@ -66,9 +77,9 @@ async def run(
         )
     if not choice or choice.lower().startswith("y"):
         if "release" not in skip:
-            hub.log.info("Pushing to pypi")
+            print("Releasing to repository")
             await hub.pop_release.twine.push(ctx, root_path)
         if "push" not in skip:
-            hub.log.info("Pushing to git")
+            print(f"Pushing to git remote: {remote}")
             hub.pop_release.git.push(root_path, remote)
     print("Success!")
